@@ -1,4 +1,4 @@
-# $Id: twitter.py 1087 2014-10-22 20:41:31Z mwall $
+# $Id: twitter.py 1156 2014-12-03 19:44:45Z mwall $
 # Copyright 2014 Matthew Wall
 """
 Tweet weather data
@@ -75,10 +75,15 @@ import time
 import weewx
 import weewx.restx
 import weewx.units
+from weeutil.weeutil import to_bool, accumulateLeaves
 
 from twython import Twython, TwythonError, TwythonAuthError, TwythonRateLimitError
 
-VERSION = "0.6"
+VERSION = "0.7"
+
+if weewx.__version__ < "3":
+    raise weewx.UnsupportedFeature("weewx 3 is required, found %s" %
+                                   weewx.__version__)
 
 def logmsg(level, msg):
     syslog.syslog(level, 'restx: Twitter: %s' % msg)
@@ -135,7 +140,8 @@ class Twitter(weewx.restx.StdRESTbase):
         super(Twitter, self).__init__(engine, config_dict)
         loginf('service version is %s' % VERSION)
         try:
-            site_dict = weewx.restx.get_dict(config_dict, 'Twitter')
+            site_dict = config_dict['StdRESTful']['Twitter']
+            site_dict = accumulateLeaves(site_dict, max_level=1)
             site_dict['app_key']
             site_dict['app_key_secret']
             site_dict['oauth_token']
@@ -182,13 +188,13 @@ class TwitterThread(weewx.restx.RESTThread):
     def __init__(self, queue, 
                  app_key, app_key_secret, oauth_token, oauth_token_secret,
                  station, format, format_None, format_utc=True,
-                 unit_system=None, 
+                 unit_system=None, skip_upload=False,
                  log_success=True, log_failure=True,
                  post_interval=None, max_backlog=sys.maxint, stale=None,
                  timeout=60, max_tries=3, retry_wait=5):
         super(TwitterThread, self).__init__(queue,
                                             protocol_name='Twitter',
-                                            database_dict=None,
+                                            manager_dict=None,
                                             post_interval=post_interval,
                                             max_backlog=max_backlog,
                                             stale=stale,
@@ -206,6 +212,7 @@ class TwitterThread(weewx.restx.RESTThread):
         self.format_None = format_None
         self.format_utc = format_utc
         self.unit_system = unit_system
+        self.skip_upload = to_bool(skip_upload)
 
     def format_tweet(self, record):
         msg = self.format
@@ -234,15 +241,18 @@ class TwitterThread(weewx.restx.RESTThread):
                 else:
                     newstr = fmt % record[obs]
                 msg = msg.replace(oldstr, newstr)
+        logdbg('msg: %s' % msg)
         return msg
 
-    def process_record(self, record, dummy_archive):
+    def process_record(self, record, dummy_manager):
         if self.unit_system is not None:
             record = weewx.units.to_std_system(record, self.unit_system)
         record['station'] = self.station
 
         msg = self.format_tweet(record)
-        logdbg(msg)
+        if self.skip_upload:
+            loginf('skipping upload')
+            return
 
         # now do the posting
         ntries = 0
